==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CalloutLabelUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutLabelUpdatingEventArgsDescription } from "./CalloutLabelUpdatingEventArgsDescription";
/**
 * @hidden
 */
var CalloutLabelUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CalloutLabelUpdatingEventArgsDescriptionMetadata, _super);
    function CalloutLabelUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalloutLabelUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (CalloutLabelUpdatingEventArgsDescriptionMetadata.a == null) {
            CalloutLabelUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalloutLabelUpdatingEventArgsDescriptionMetadata.c(CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.j(CalloutLabelUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    CalloutLabelUpdatingEventArgsDescriptionMetadata.c = function (a) {
        a.item("XValueRef", "(w:XValue,j:xValue,wf:XValue)DataRef");
        a.item("YValueRef", "(w:YValue,j:yValue,wf:YValue)DataRef");
        a.item("ItemRef", "(w:Item,j:item,wf:Item)DataRef");
        a.item("Series", "ExportedType:Series");
        a.item("SeriesName", "String");
        a.item("LabelRef", "(w:Label,j:label,wf:Label)DataRef");
    };
    CalloutLabelUpdatingEventArgsDescriptionMetadata.d = function (a) {
        CalloutLabelUpdatingEventArgsDescriptionMetadata.b(a);
        a.aa("CalloutLabelUpdatingEventArgs", function () { return new CalloutLabelUpdatingEventArgsDescription(); });
        a.z("CalloutLabelUpdatingEventArgs", CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
    };
    CalloutLabelUpdatingEventArgsDescriptionMetadata.$t = markType(CalloutLabelUpdatingEventArgsDescriptionMetadata, 'CalloutLabelUpdatingEventArgsDescriptionMetadata');
    CalloutLabelUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutLabelUpdatingEventArgsDescriptionMetadata;
}(Base));
export { CalloutLabelUpdatingEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/CalloutLabelUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutLabelUpdatingEventArgsDescription } from "./CalloutLabelUpdatingEventArgsDescription";
/**
 * @hidden
 */
var CalloutLabelUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CalloutLabelUpdatingEventArgsDescriptionMetadata, _super);
    function CalloutLabelUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalloutLabelUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (CalloutLabelUpdatingEventArgsDescriptionMetadata.a == null) {
            CalloutLabelUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalloutLabelUpdatingEventArgsDescriptionMetadata.c(CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.k(CalloutLabelUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    CalloutLabelUpdatingEventArgsDescriptionMetadata.c = function (a) {
        a.item("XValueRef", "(w:XValue,j:xValue,wf:XValue)DataRef");
        a.item("YValueRef", "(w:YValue,j:yValue,wf:YValue)DataRef");
        a.item("ItemRef", "(w:Item,j:item,wf:Item)DataRef");
        a.item("Series", "ExportedType:Series");
        a.item("SeriesName", "String");
        a.item("LabelRef", "(w:Label,j:label,wf:Label)DataRef");
    };
    CalloutLabelUpdatingEventArgsDescriptionMetadata.d = function (a) {
        CalloutLabelUpdatingEventArgsDescriptionMetadata.b(a);
        a.ac("CalloutLabelUpdatingEventArgs", function () { return new CalloutLabelUpdatingEventArgsDescription(); });
        a.ab("CalloutLabelUpdatingEventArgs", CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
    };
    CalloutLabelUpdatingEventArgsDescriptionMetadata.$t = markType(CalloutLabelUpdatingEventArgsDescriptionMetadata, 'CalloutLabelUpdatingEventArgsDescriptionMetadata');
    CalloutLabelUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutLabelUpdatingEventArgsDescriptionMetadata;
}(Base));
export { CalloutLabelUpdatingEventArgsDescriptionMetadata };
